<?php
/**
 * Plugin Name: Spend X Free Shipping
 * Plugin URI: https://demo.lovethemes.co/
 *
 * Description: Spend X Free Shipping helps to increase your stores average order value by enticing the customer to purchase more products in order to receive free shipping.
 *
 * Author: LoveThemes
 * Author URI: https://lovethemes.co/
 *
 * Version: 20200501
 *
 * Text Domain: lovethemes
 *
 * @package WordPress\Spend X Free Shipping
 */
class LoveThemes_Spend_X_Free_Shipping_Notice {

	public function free_shipping_cart_notice()
	{
		global $woocommerce;

		// get free shipping methods for Rest of the World Zone & populate array $min_amounts
		$default_zone    = new WC_Shipping_Zone(0);
		$default_methods = $default_zone->get_shipping_methods();

		foreach( $default_methods as $key => $value )
		{
	    	if ( $value->id === "free_shipping" )
	    	{
				if ( $value->min_amount > 0 ) $min_amounts[] = $value->min_amount;
	    	}
		}

		// get free shipping methods for all other zones & populate array $min_amounts
		$delivery_zones = WC_Shipping_Zones::get_zones();

		foreach ( $delivery_zones as $key => $delivery_zone )
		{
			foreach ( $delivery_zone['shipping_methods'] as $key => $value )
			{
				if ( $value->id === "free_shipping" )
				{
					if ( $value->min_amount > 0 ) $min_amounts[] = $value->min_amount;
	    		}
	  		}
		}

		// find lowest min_amount
		if ( is_array($min_amounts) )
		{
			$min_amount = min($min_amounts);

			// get cart subtotal excluding shipping
			$current = WC()->cart->subtotal;

			// subtotal < min amount display notice
			if ( $current < $min_amount )
			{
				// get plugin options
				$options       = get_option( 'spendx_option_name' );
				$before_text   = $options['before_text']; // sanitized on input with wp_kses()
				$after_text    = $options['after_text']; // sanitized on input with wp_kses()
				$button_colour = esc_attr( $options['button_colour'] );
				$button_text   = esc_html( $options['button_text'] );

				// the text notice
				$added_text = '<span class="lovethemes-alignleft">' . $before_text . '<b>&nbsp;' . wc_price( $min_amount - $current ) . '&nbsp;</b>' . $after_text . '</span>';

				// get the shop page to return to
				$return_to  = apply_filters( 'woocommerce_continue_shopping_redirect', wc_get_raw_referer() ? wp_validate_redirect( wc_get_raw_referer(), false ) : wc_get_page_permalink( 'shop' ) );

				// output the notice and button
				$notice = sprintf( '
					%s <a style="background:'.$button_colour.'" href="%s" class="animated infinite pulse button lovethemes-alignright wc-forward">%s</a>',
					$added_text,
					esc_url( $return_to ),
					$button_text
				);

				wc_print_notice( $notice, 'notice' );
			}
	 	}
	}
}