<?php
/**
 * Plugin Name: Spend X Free Shipping
 * Plugin URI: https://demo.lovethemes.co/
 *
 * Description: Spend X Free Shipping helps to increase your stores average order value by enticing the customer to purchase more products in order to receive free shipping.
 *
 * Author: LoveThemes
 * Author URI: https://lovethemes.co/
 *
 * Version: 20200501
 *
 * Text Domain: lovethemes
 *
 * @package WordPress\Spend X Free Shipping
 */
class LoveThemes_Spend_X_Free_Shipping_Options {
    /**
     * Instantiate options
     */
	private $options;
	public function __construct()
    {
		add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'page_init' ) );
	}
    /**
     * Add plugin page menu
     */
	public function add_plugin_page()
    {
		add_menu_page( 'WooCommerce Spend X', 'WooCommerce Spend X', 'manage_options', 'lovethemes-woocommerce-spend-x-free-shipping', array( $this, 'create_spendx_settings_page' ), 'dashicons-cart', 99 );
	}
    /**
     * Create options page
     */
	public function create_spendx_settings_page()
    {
		$this->options = get_option( 'spendx_option_name' );
    ?>
		<div class="wrap">
			<h2><?php esc_html_e( 'Spend X Free Shipping', 'lovethemes' ); ?></h2>
            <h4><?php esc_html_e( 'Spend X Free Shipping helps to increase your stores average order value by enticing the customer to purchase more products in order to receive free shipping.', 'lovethemes' ); ?></h4>

			<hr>

			<?php settings_errors(); ?>

			<form method="post" action="options.php">
				<?php
					settings_fields( 'spendx_option_group' );
					do_settings_sections( 'spendx_settings' );
					submit_button();
				?>
			</form>
		</div>
	<?php
    }
    /**
     * Register page settings
     */
	public function page_init()
    {
		/**
		 * Register Settings
		 */
		register_setting( 'spendx_option_group', 'spendx_option_name', array( $this, 'sanitize' ) );
		/**
		 * Add Settings Section
		 */
		add_settings_section( 'spendx_setting_section', 'Settings', array( $this, 'section_info' ), 'spendx_settings' );
		/**
		 * Before Text Setting
		 */
		add_settings_field( 'before_text', 'Before Price Text', array( $this, 'before_text_callback' ), 'spendx_settings', 'spendx_setting_section' );
		/**
		 * After Text Setting
		 */
        add_settings_field( 'after_text', 'After Price Text', array( $this, 'after_text_callback' ), 'spendx_settings', 'spendx_setting_section' );
		/**
		 * Button Colour
		 */
		add_settings_field( 'button_colour', 'Button Colour', array( $this, 'button_colour_callback' ), 'spendx_settings', 'spendx_setting_section' );
		/**
		 * Button Text Setting
		 */
		add_settings_field( 'button_text', 'Button Text', array( $this, 'button_text_callback' ), 'spendx_settings', 'spendx_setting_section' );
	}
    /**
     * Sanitize Options
     */
	public function sanitize($input)
    {
		$sanitized = array();

		$allowed_html = array(
		    'a' => array(
		        'href' => array(),
		        'title' => array()
		    ),
		    'br' => array(),
		    'em' => array(),
		    'strong' => array(),
			'b' => array(),
		);

		if ( isset( $input['before_text'] ) )
        {
			$sanitized['before_text'] = wp_kses( $input['before_text'], $allowed_html );
		}

        if ( isset( $input['after_text'] ) )
        {
			$sanitized['after_text'] = wp_kses( $input['after_text'], $allowed_html );
		}

		if ( isset( $input['button_colour'] ) )
		{
			$sanitized['button_colour'] = sanitize_text_field( $input['button_colour'] );
		}

		if ( isset( $input['button_text'] ) )
        {
			$sanitized['button_text'] = sanitize_text_field( $input['button_text'] );
		}

		return $sanitized;
	}
    /**
     * Options page info section
     */
	public function section_info()
    {
		$anchor_text = esc_html__( 'WooCommerce Shipping Options', 'lovethemes' );
		$anchor      = esc_url( get_site_url( null, 'wp-spendx_settings/spendx_settings.php?page=wc-settings&tab=shipping', 'relative' ) );
		$link        = sprintf( '<a href="%s">%s</a>', $anchor, $anchor_text );

 		/* translators: 1 is a link with text "WooCommerce Shipping Options" and URL spendx_settings.php?page=wc-settings&tab=shipping */
		echo sprintf( esc_html__( 'The price remaining for free shipping is automatically generated from the %1$s and the cart amount. You can add text to appear before the price and text to appear after. You can also customize the text displayed on the Continue Shopping button.', 'lovethemes' ), $link );
	}
    /**
     * Options callbacks
     */
	public function before_text_callback()
    {
		printf(
			'<input class="regular-text" type="text" name="spendx_option_name[before_text]" id="before_text" value="%s" placeholder="'.esc_attr__('You are only','lovethemes').'">',
			isset( $this->options['before_text'] ) ? esc_attr( $this->options['before_text']) : ''
		);
	}

    public function after_text_callback()
    {
		printf(
			'<input class="regular-text" type="text" name="spendx_option_name[after_text]" id="after_text" value="%s" placeholder="'.esc_attr__('away from receiving FREE shipping.','lovethemes').'">',
			isset( $this->options['after_text'] ) ? esc_attr( $this->options['after_text']) : ''
		);
	}

	public function button_colour_callback()
	{
		printf(
			'<input type="regular-text" name="spendx_option_name[button_colour]" id="button_colour" value="'.esc_attr( $this->options['button_colour']).'" class="lovethemes-button-color-picker" />',
			isset( $this->options['button_colour'] ) ? esc_attr( $this->options['button_colour']) : '#cd2653'
		);
	}

	public function button_text_callback()
    {
		printf(
			'<input class="regular-text" type="text" name="spendx_option_name[button_text]" id="button_text" value="%s" placeholder="'.esc_attr__('Continue Shopping','lovethemes').'">',
			isset( $this->options['button_text'] ) ? esc_attr( $this->options['button_text']) : ''
		);
	}
}
if ( is_admin() )
{
	new LoveThemes_Spend_X_Free_Shipping_Options();
}